@@ -25,8 +25,7 @@ __all__ = ('Client',)
 
 
 class Client(MethodClientABC):
-    """
-        Synchronous Python SDK for the VALR REST API.
+    """Synchronous Python SDK for the VALR REST API.
 
             >>> from valr_python import Client
             >>> from valr_python.exceptions import IncompleteOrderWarning
@@ -53,8 +52,8 @@ class Client(MethodClientABC):
             >>>
         """
 
-    def _do(self, method: str, path: str, data: Optional[Dict] = None,
-            is_authenticated: bool = False) -> Optional[Union[List, Dict]]:
+    def _do(self, method: str, path: str, data: Optional[Dict] = None, params: Optional[Dict] = None,
+            is_authenticated: bool = False, subaccount_id: str = '') -> Optional[Union[List, Dict]]:
         """Executes API request and returns the response.
 
         Includes HTTP 429 handling by honouring VALR's 429 Retry-After header cool-down.
@@ -64,10 +63,13 @@ class Client(MethodClientABC):
             data = json.dumps(data, cls=DecimalEncoder)  # serialize decimals as str
             headers["Content-Type"] = "application/json"
         if is_authenticated:
+            # todo - fix data processing in valr headers
             headers.update(_get_valr_headers(api_key=self.api_key, api_secret=self.api_secret, method=method,
-                                             path=path, data=data))
+                                             path=path, data=data, subaccount_id=subaccount_id))
         url = self._base_url + '/' + path.lstrip('/')
         args = dict(timeout=self._timeout, data=data, headers=headers)
+        if params:
+            args['params'] = params
         res = self._session.request(method, url, **args)
 
         try:
